@@ -57,7 +57,7 @@ void SkinListDelegate::paint(QPainter* painter, const QStyleOptionViewItem& opti
 
 void SkinListDelegate::paintBackground(QPainter* painter, const QStyleOptionViewItem& option) const
 {
-    QStyleOptionViewItemV4 opt = option;
+    QStyleOptionViewItem opt = option;
     QStyle* style = opt.widget ? opt.widget->style() : QApplication::style();
     style->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, painter, opt.widget);
 }
