@@ -26,13 +26,10 @@
 #include <KLocalizedString>
 
 #include <QApplication>
-
+#include <QCommandLineParser>
 
 int main (int argc, char *argv[])
 {
-#if HAVE_X11
-    qputenv("QT_QPA_PLATFORM", QByteArrayLiteral("xcb"));
-#endif
     QApplication app(argc, argv);
     app.setQuitOnLastWindowClosed(false);
 
@@ -40,10 +37,10 @@ int main (int argc, char *argv[])
 
     KAboutData aboutData(QStringLiteral("yakuake"),
         xi18nc("@title", "<application>Yakuake</application>"),
-        QStringLiteral("3.0.2"),
+        QStringLiteral("3.0.3"),
         xi18nc("@title", "A drop-down terminal emulator based on KDE Konsole technology."),
         KAboutLicense::GPL,
-        xi18nc("@info:credit", "(c) 2008-2016 The Yakuake Team"),
+        xi18nc("@info:credit", "(c) 2008-2017 The Yakuake Team"),
         QString(),
         QStringLiteral("http://yakuake.kde.org/"));
 
@@ -67,6 +64,13 @@ int main (int argc, char *argv[])
                             i18nc("EMAIL OF TRANSLATORS", "Your emails"));
 
     KAboutData::setApplicationData(aboutData);
+    QCommandLineParser parser;
+    parser.addHelpOption();
+    parser.addVersionOption();
+
+    aboutData.setupCommandLine(&parser);
+    parser.process(app);
+    aboutData.processCommandLine(&parser);
 
     app.setApplicationName(aboutData.componentName());
     app.setApplicationDisplayName(aboutData.displayName());
