@@ -40,6 +40,13 @@ class TitleBar;
 class KHelpMenu;
 class KActionCollection;
 
+#if HAVE_KWAYLAND
+namespace KWayland {
+    namespace Client {
+        class PlasmaShell;
+    }
+}
+#endif
 
 class MainWindow : public QMainWindow
 {
@@ -83,6 +90,7 @@ class MainWindow : public QMainWindow
         virtual void paintEvent(QPaintEvent*);
         virtual void moveEvent(QMoveEvent*);
         virtual void changeEvent(QEvent* event);
+        virtual bool event(QEvent* event);
 
         virtual bool queryClose();
 
@@ -189,6 +197,14 @@ class MainWindow : public QMainWindow
         int m_animationStepSize;
 
         bool m_toggleLock;
+
+        bool m_isX11;
+        bool m_isWayland;
+
+#if HAVE_KWAYLAND
+        void initWayland();
+        KWayland::Client::PlasmaShell *m_plasmaShell;
+#endif
 };
 
 #endif
