@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2008-2009 by Eike Hein <hein@kde.org>
+  Copyright (C) 2008-2014 by Eike Hein <hein@kde.org>
   Copyright (C) 2009 by Juan Carlos Torres <carlosdgtorres@gmail.com>
 
   This program is free software; you can redistribute it and/or
@@ -22,17 +22,22 @@
 
 #include "sessionstack.h"
 #include "settings.h"
+#include "terminal.h"
 #include "visualeventoverlay.h"
 
+#include "config-yakuake.h"
+
 #include <KMessageBox>
 #include <KLocalizedString>
+#include <KNotification>
 
 #include <QtDBus/QtDBus>
 
+static bool show_disallow_certain_dbus_methods_message = true;
 
 SessionStack::SessionStack(QWidget* parent) : QStackedWidget(parent)
 {
-    QDBusConnection::sessionBus().registerObject("/yakuake/sessions", this, QDBusConnection::ExportScriptableSlots);
+    QDBusConnection::sessionBus().registerObject(QStringLiteral("/yakuake/sessions"), this, QDBusConnection::ExportScriptableSlots);
 
     m_activeSessionId = -1;
 
@@ -62,7 +67,7 @@ int SessionStack::addSession(Session::SessionType type)
     if (Settings::dynamicTabTitles())
         emit sessionAdded(session->id(), session->title());
     else
-        emit sessionAdded(session->id());
+        emit sessionAdded(session->id(), QString());
 
     return session->id();
 }
@@ -191,7 +196,7 @@ const QString SessionStack::sessionIdList()
     while (i.hasNext())
         idList << QString::number(i.next());
 
-    return idList.join(",");
+    return idList.join(QStringLiteral(","));
 }
 
 const QString SessionStack::terminalIdList()
@@ -207,7 +212,7 @@ const QString SessionStack::terminalIdList()
         idList << it.value()->terminalIdList();
     }
 
-    return idList.join(",");
+    return idList.join(QStringLiteral(","));
 }
 
 const QString SessionStack::terminalIdsForSessionId(int sessionId)
@@ -238,8 +243,21 @@ int SessionStack::sessionIdForTerminalId(int terminalId)
     return sessionId;
 }
 
+static void warnAboutDBus()
+{
+#if !defined(REMOVE_SENDTEXT_RUNCOMMAND_DBUS_METHODS)
+    if (show_disallow_certain_dbus_methods_message) {
+        KNotification::event(KNotification::Warning, QStringLiteral("Yakuake D-Bus Warning"),
+            i18n("The D-Bus method runCommand was just used.  There are security concerns about allowing these methods to be public.  If desired, these methods can be changed to internal use only by re-compiling Yakuake. <p>This warning will only show once for this Yakuake instance.</p>"));
+        show_disallow_certain_dbus_methods_message = false;
+    }
+#endif
+}
+
 void SessionStack::runCommand(const QString& command)
 {
+    warnAboutDBus();
+
     if (m_activeSessionId == -1) return;
     if (!m_sessions.contains(m_activeSessionId)) return;
 
@@ -248,6 +266,8 @@ void SessionStack::runCommand(const QString& command)
 
 void SessionStack::runCommandInTerminal(int terminalId, const QString& command)
 {
+    warnAboutDBus();
+
     QHashIterator<int, Session*> it(m_sessions);
 
     while (it.hasNext())
@@ -594,6 +614,21 @@ void SessionStack::handleTerminalHighlightRequest(int terminalId)
     }
 }
 
+void SessionStack::showEvent(QShowEvent *event)
+{
+    Q_UNUSED(event)
+
+    if (m_activeSessionId == -1) return;
+    if (!m_sessions.contains(m_activeSessionId)) return;
+
+    Terminal *terminal = m_sessions.value(m_activeSessionId)->getTerminal(activeTerminalId());
+
+    if (terminal) {
+        QWidget* terminalWidget = terminal->terminalWidget();
+        if (terminalWidget) terminalWidget->setFocus();
+    }
+}
+
 void SessionStack::handleManualTerminalActivation(Terminal* terminal)
 {
     if (!Settings::terminalHighlightOnManualActivation())
@@ -611,17 +646,17 @@ bool SessionStack::queryClose(int sessionId, QueryCloseType type)
 
     if (!m_sessions.value(sessionId)->closable())
     {
-        QString closeQuestionIntro = i18nc("@info", "<warning>You have locked this session to prevent accidental closing of terminals.</warning>");
+        QString closeQuestionIntro = xi18nc("@info", "<warning>You have locked this session to prevent accidental closing of terminals.</warning>");
         QString closeQuestion;
 
         if (type == QueryCloseSession)
-            closeQuestion = i18nc("@info", "Are you sure you want to close this session?");
+            closeQuestion = xi18nc("@info", "Are you sure you want to close this session?");
         else if (type == QueryCloseTerminal)
-            closeQuestion = i18nc("@info", "Are you sure you want to close this terminal?");
+            closeQuestion = xi18nc("@info", "Are you sure you want to close this terminal?");
 
         int result = KMessageBox::warningContinueCancel(this,
-            closeQuestionIntro + "<br/><br/>" + closeQuestion,
-            i18nc("@title:window", "Really Close?"), KStandardGuiItem::close(), KStandardGuiItem::cancel());
+            closeQuestionIntro + QStringLiteral("<br/><br/>") + closeQuestion,
+            xi18nc("@title:window", "Really Close?"), KStandardGuiItem::close(), KStandardGuiItem::cancel());
 
         if (result != KMessageBox::Continue)
             return false;
